***************************************************************************************
*   Function DoMsgbox()
***************************************************************************************
* FUNCTION DoMsgbox
PARAMETERS pcMessage, pcTitle, pnType

* This procedure displays a Windows message box in either Visual FoxPro or FoxPro
* for Windows 2.x.
* Under VFP it issues a call to the native messagebox() function.
* Under FPW it wraps around a call to msgbox() in foxtools.fll.  It includes logic to 
* find and set foxtools if necessary.
* 
* Assumptions:  1. #DEFINE statements have been established for msgbox() dialog box type
*                  and return codes, as documented in \GOODIES\FOXTOOLS\FOXTOOLS.WRI.
*                  (Visual FoxPro predefines these values in FOXPRO.H).
*
* Sample call:  m.lnChoice = DoMsgbox('Do you want to continue?', ;
*                                   'An error has occured', ;
*                                    MB_YESNO + MB_ICONEXPLANATION)

PRIVATE m.lnChoice, m.lcLibName

m.lnChoice = 2             && 2 = Cancel

IF PARAMETERS() < 3
   WAIT WINDOW 'DEV: DoMsgbox() requires 3 parameters (message, title, dialog type)'
   RETURN m.lnChoice
ENDIF

* Handle different FoxPro versions.  Visual FoxPro calls messagebox() with dialog box type as 
* the second parameter and window title text as the third parameter.  FoxPro for Windows 2.x
* calls msgbox() in FOXTOOLS with those parameters reversed.

DO CASE
CASE 'Visual FoxPro' $ VERSION()
   RETURN (messagebox(pcMessage, pnType, pcTitle))
OTHERWISE
* Foxtools library already loaded?
   IF NOT 'FOXTOOLS' $ UPPER(SET('LIBRARY',1))
      * No - is it in FoxPro startup directory?
      IF FILE(SYS(2004)+'foxtools.fll')
         m.lcLibName = SYS(2004)+'foxtools.fll'
      ELSE
         m.lcLibName = GETFILE('FLL','Where is FOXTOOLS.FLL?')
      ENDIF
      * Bail out if we don't have a good foxtools.fll location
      IF EMPTY(m.lcLibName) OR NOT 'FOXTOOLS.FLL' $ UPPER(m.lcLibName)
         RETURN m.lnChoice
      ELSE
         SET LIBRARY TO (m.lcLibName) ADDITIVE
      ENDIF
   ENDIF
   RETURN (msgbox(pcMessage, pcTitle, pnType))
ENDCASE

RETURN



